declare module BA.Ui.Dialog {
    class ConfigurationDialogManager {
        /**
         * This function is meant to be used by a configuration dialog user in order to invoke a configuration dialog by form dialog model.
         * Whatever the user passes as the additionalData parameter will be returned as second
         * parameter on the given onClose function. The first parameter of that onClose function will be the
         * DialogResult which contains all the information which the dialog user hoped to retrieve from calling
         * this dialog.
         *
         * @param configurationGuid the guid of the configuration to open
         * @param dialogWidth desired width of the dialog
         * @param dialogHeight desired height of the dialog
         * @param customData data that will be routed through the dialog and passed to the onClose function
         * @param onClose function that will be called when the dialog closes; parameter 1 will be the DialogResult,
         *              parameter 2 will be the additionalData
         */
        static OpenDialog(configurationGuid: string, dialogWidth?: number, dialogHeight?: number, customData?: CustomData, onClose?: Function): void;
        /**
         * Submits the form to the server. The configuration will be saved if it is valid.
         * @param window The context window
         * @param button The pressed dialog button
         * @param evt The event object
         */
        static SubmitConfiguration(button: BADialogButton, evt: ASPxClientButtonClickEventArgs): void;
        /**
         * The ajax submit on success default handling
         * @param data The data object
         * @param status The return status
         * @param xhr The xhr object
         */
        static PopupFormSuccess(data: any, status: any, xhr: any): void;
        /**
         *  Ask user if delete is really wanted
         */
        static DeleteOrCancel(s: any, e: any): void;
        /**
         * Open properties of configuration for creation
         * @param e
         * @param customData
         */
        static OpenPropertiesDialogForCreate(event: any, customData: CustomData): void;
        /**
         * Open properties of configuration for edit
         * @param e
         * @param customData
         */
        static OpenPropertiesDialog(event: any, customData: CustomData): void;
        /**
         * Open properties of configuration for edit
         * @param sender
         * @param e
         */
        static SavePropertiesDialog(sender: any, e: any): void;
    }
}
